import { Component, Input, ViewChild, NgModule } from '@angular/core';
import { Chart } from 'chart.js';
import randomColor from 'randomcolor';
import 'rxjs';
import { DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
import { MatIconRegistry, MatIconModule } from '@angular/material';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChartJsComponent {
    /**
     * @param {?} iconRegistry
     * @param {?} sanitizer
     */
    constructor(iconRegistry, sanitizer) {
        this.iconRegistry = iconRegistry;
        this.sanitizer = sanitizer;
        this.chartData = [];
        this.hasData = false;
        this.chart = null;
        this.registerIcons();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set data(value) {
        this.chartData = value;
        this.hasData = this.chartData.data.length !== 0;
        if (!this.ctx) {
            this.initChart();
        }
        this.updateData();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.updateChart.subscribe((/**
         * @return {?}
         */
        () => {
            this.updateData();
        }));
    }
    /**
     * @return {?}
     */
    initChart() {
        this.ctx = this.canvasRef.nativeElement.getContext('2d');
        switch (this.type) {
            case 'chart.pie': {
                this.createChartPie();
                break;
            }
            case 'chart.bar': {
                this.createChartBar();
                break;
            }
            case 'chart.column': {
                this.createChartColumn();
                break;
            }
            default: {
                console.warn('Chart couldn\'t be generated');
                break;
            }
        }
    }
    /**
     * @return {?}
     */
    createChartPie() {
        this.chart = new Chart(this.ctx, {
            type: 'pie',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    }
    /**
     * @return {?}
     */
    createChartBar() {
        this.chart = new Chart(this.ctx, {
            type: 'horizontalBar',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    }
    /**
     * @return {?}
     */
    createChartColumn() {
        this.chart = new Chart(this.ctx, {
            type: 'bar',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    }
    /**
     * @return {?}
     */
    dynamicColors() {
        /** @type {?} */
        const color = randomColor({
            count: this.chartData.data.length + 1,
            format: 'rgb',
            luminosity: 'light',
            hue: 'random',
        });
        return color;
    }
    /**
     * @return {?}
     */
    updateData() {
        if (this.chart) {
            this.chart.data.labels = this.chartData.labels ? this.chartData.labels : [];
            this.chart.data.datasets = [{
                    label: this.chartData.series ? this.chartData.series : null,
                    data: this.chartData.data ? this.chartData.data : [],
                    backgroundColor: this.dynamicColors(),
                }];
            this.chart.update();
        }
    }
    /**
     * @private
     * @return {?}
     */
    registerIcons() {
        this.iconRegistry.addSvgIcon('bar_chart', this.sanitizer.bypassSecurityTrustResourceUrl('assets/chart-js-module/icons/baseline-bar_chart-24px.svg'));
    }
}
ChartJsComponent.decorators = [
    { type: Component, args: [{
                selector: 'chartjs-chart',
                template: "<div class=\"chart-container\">\n  <canvas #canvas [ngStyle]=\"{'visibility': hasData ? 'visible' : 'hidden'}\">{{chart}}</canvas>\n  <div class=\"no-data\" *ngIf=\"!hasData\">\n    <mat-icon svgIcon=\"bar_chart\" class=\"icon\"></mat-icon>\n    <span class=\"text\">No hay datos disponibles</span>\n  </div>\n</div>\n",
                styles: [".chart-container{max-width:100%!important;overflow-y:auto}.chart-container canvas{max-height:100%;max-width:100%}.chart-container .no-data{position:absolute;top:0;width:100%;text-align:center;margin-top:32px}.chart-container .no-data mat-icon,.chart-container .no-data span{display:block;margin:auto}"]
            }] }
];
/** @nocollapse */
ChartJsComponent.ctorParameters = () => [
    { type: MatIconRegistry },
    { type: DomSanitizer }
];
ChartJsComponent.propDecorators = {
    type: [{ type: Input }],
    data: [{ type: Input }],
    label: [{ type: Input }],
    updateChart: [{ type: Input }],
    canvasRef: [{ type: ViewChild, args: ['canvas',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChartJsModule {
}
ChartJsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    MatIconModule
                ],
                declarations: [
                    ChartJsComponent
                ],
                providers: [],
                exports: [
                    ChartJsComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ChartJsModule, ChartJsComponent };

//# sourceMappingURL=biosoftcl-chart-js-module.js.map